function createfigure(X1, Y1, S1, C1)
%CREATEFIGURE(X1,Y1,S1,C1)
%  X1:  scatter x
%  Y1:  scatter y
%  S1:  scatter s
%  C1:  scatter c

%  Auto-generated by MATLAB on 23-Mar-2009 20:04:11

% Create figure
figure1 = figure('XVisual',...
    '0x21 (TrueColor, depth 16, RGB mask 0xf800 0x07e0 0x001f)',...
    'PaperSize',[20.98 29.68]);

% Create axes
axes('Parent',figure1,'YTickLabel',{'0,01','0,03','0,04'},...
    'YTick',[0.01 0.03 0.04],...
    'XTickLabel',{'0,1','0,3','0,4','0,5','0,6','0,7','0,8'},...
    'XTick',[0.1 0.3 0.4 0.5 0.6 0.7 0.8],...
    'Position',[0.05754 0.04987 0.88 0.8717],...
    'FontWeight','bold',...
    'FontSize',20,...
    'FontName','Arial');
hold('all');

% Create scatter
scatter(X1,Y1,S1,C1,'MarkerFaceColor',[0.9255 0.8392 0.8392],...
    'Marker','square');

% Create xlabel
xlabel('Mean µ','FontWeight','bold','FontSize',30,'FontName','Arial');

% Create ylabel
ylabel('Variance \sigma^2','FontWeight','bold','FontSize',30,...
    'FontName','Arial');

% Create textbox
annotation(figure1,'textbox',...
    'String',{'Mean and variances from time-window based efficiencies'},...
    'FontWeight','bold',...
    'FontSize',24,...
    'FontName','Arial',...
    'FontAngle','oblique',...
    'FitBoxToText','off',...
    'LineStyle','none',...
    'EdgeColor',[1 1 1],...
    'Position',[0.0602 0.9176 0.8874 0.05098],...
    'Color',[0.07843 0.1686 0.549]);

